=================
Functions
=================
.. currentmodule:: polars

Config
~~~~~~
.. autosummary::
   :toctree: api/

    toggle_string_cache
    StringCache

Conversion
~~~~~~~~~~
.. autosummary::
   :toctree: api/

    from_arrow
    from_dict
    from_dicts
    from_numpy
    from_pandas
    from_records

Eager/Lazy functions
~~~~~~~~~~~~~~~~~~~~
.. autosummary::
   :toctree: api/

   arg_where
   concat
   cut
   date_range
   get_dummies
   repeat

Parallelization
~~~~~~~~~~~~~~~
.. autosummary::
   :toctree: api/

   collect_all
   threadpool_size
